﻿Copyright (c) (2017) Fluke corporation                      MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Wait for Operation Complete (OPC) VISA SCPI
DATE:                  2017-12-19 10:19:48
AUTHOR:                Fluke Calibration
REVISION:              $Revision: 21946 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       104
=============================================================================
#
#  Procedure Author:
#        DAC
#
#  Models covered:
#        All SCPI compliant DUTs controlled via the VISA FSC
#
#  Compatibility:
#        MET/CAL 8.0 or later
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Precision Measurement
#  Limited.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON
#
# Global Variables:
#   Input
#     @Cmd      Command to send
#     @Timeout  Timeout in milliseconds
#   Output
#     @Abort    0 if success, 1 if error and operator decided to abort
#
  1.001  MATH         Error = 0; OPC = 0
  1.002  VISA         [V @Cmd];*OPC

  1.003  DO

  1.004  IF           ISVAR("@Timeout")
  1.005  MATH         TimeRemaining = @Timeout
  1.006  ELSE
# Default timeout to 20 minutes if not specified.
  1.007  MATH         TimeRemaining = 1200000
  1.008  ENDIF

# Query the Extended Status Register (ESR) until a bit is set.
  1.009  DO
  1.010  WAIT         [D100]
  1.011  VISA         *ESR?[I]
  1.012  MATH         TimeRemaining = TimeRemaining - 100
  1.013  MATH         TimedOut = (TimeRemaining <= 0)
  1.014  UNTIL        (MEM > 0) || TimedOut

  1.015  IF           TimedOut
  1.016  MATH         Error = 1
  1.017  DISP         Timeout waiting for Operation Complete (OPC).
  1.018  ELSE

# ESR Bit Definitions:
#
#   Bit 7: PON "Power On", ignored
#   Bit 6: URQ "User Request" ignored
#   Bit 5: CME "Command Error"
#   Bit 4: EXE "Execution Error"
#   Bit 3: DDE "Device Dependent Error"
#   Bit 2: QYE "Query Error"
#   Bit 1: RQC "Request Control", ignored
#   Bit 0: OPC "Operation Complete"
  1.019  MATH         Error = BIT(5, MEM)
  1.020  MATH         Error = BIT(4, MEM) || Error
  1.021  MATH         Error = BIT(3, MEM) || Error
  1.022  MATH         Error = BIT(2, MEM) || Error

# Retrieve the SCPI errors if any error bit was set in the ESR.
  1.023  IF           Error
  1.024  CALL         Sub Display SCPI Errors VISA

# If no error bits were set, check bit 0 (OPC)
  1.025  ELSEIF       BIT(0, MEM)
  1.026  MATH         OPC = 1
  1.027  ENDIF

  1.028  ENDIF        ; TimedOut

  1.029  UNTIL        OPC || Error

  1.030  IF           Error
  1.031  OPBR         Do you wish to continue?
  1.032  MATH         @Abort = NOT(MEM1)
  1.033  ELSE
  1.034  MATH         @Abort = 0
  1.035  ENDIF

  1.036  END
